@@ -1,15 +1,17 @@
+import os.path
 import logging
-import argh
-
 logger = logging.getLogger('giza.operations.deploy')
 
-from giza.config.helper import fetch_config
+from giza.config.helper import fetch_config, new_credentials_config
 from giza.core.app import BuildApp
 from giza.deploy import Deploy
 from giza.operations.sphinx import sphinx_publication
-from giza.tools.command import verbose_command
+from giza.tools.command import command
 from giza.tools.serialization import ingest_yaml_list, dict_from_list
 
+import argh
+import onetimepass as otp
+
 @argh.arg('--target', '-t', nargs='*', dest='push_targets')
 @argh.arg('--dry-run', '-d', action='store_true', dest='dry_run')
 @argh.named('deploy')
@@ -39,7 +41,8 @@ def deploy_worker(c, app):
     pconf = c.system.files.data.push
     pconf = dict_from_list('target', pconf)
 
-    cmds = []
+    backgrounds = []
+
     for target in c.runstate.push_targets:
         d = Deploy(c)
 
@@ -50,17 +53,25 @@ def deploy_worker(c, app):
 
         d.load(target_pconf)
 
-        map_task = app.add('map')
-        map_task.iter = d.deploy_commands()
+        for cmd in d.deploy_commands():
+            task = app.add('task')
+            task.args = ' '.join(cmd)
+            task.job = command
+            task.target = ""
+            task.depends = os.path.join(c.paths.projectroot, c.paths.public_site_output)
 
-        map_task.job = verbose_command
+            if c.runstate.dry_run is True:
+                logger.info('dry run: {0}'.format(' '.join(cmd)))
+            else:
+                logger.info('deploying: {0}'.format(' '.join(cmd)))
 
-        cmds.extend(d.deploy_commands())
-
-    if c.runstate.dry_run is True:
-        for i in cmds:
-            logger.info('dry run: {0}'.format(' '.join(i)))
-    else:
+    if c.runstate.dry_run is False:
         app.run()
 
     logger.info('completed deploy for: {0}'.format(' '.join(c.runstate.push_targets)))
+
+@argh.named('code')
+def twofa_code(args):
+    creds = new_credentials_config()
+
+    print(otp.get_totp(creds.corp.seed))
